@@ -9,6 +9,7 @@ from imio.smartweb.core.behaviors.subsite import IImioSmartwebSubsite
 from imio.smartweb.core.contents import IFolder
 from imio.smartweb.locales import SmartwebMessageFactory as _
 from plone import api
+from plone.app.multilingual.interfaces import ILanguageRootFolder
 from Products.Five.browser import BrowserView
 from zope.interface import alsoProvides
 from zope.interface import noLongerProvides
@@ -18,7 +19,7 @@ class MiniSiteSettings(BrowserView):
     """Subsite settings"""
 
     def enable(self):
-        if not self.available:
+        if not self.available():
             return
         enable_behaviors(
             self.context,
@@ -45,19 +46,23 @@ class MiniSiteSettings(BrowserView):
         api.portal.show_message(_("Minisite has been disabled"), self.request)
         self.request.response.redirect(self.context.absolute_url())
 
-    @property
     def available(self):
         if IPloneSiteRoot.providedBy(self.context):
             # PloneSite can't become minisite
             return False
-        if not IPloneSiteRoot.providedBy(self.context.aq_parent):
-            # Minisite can only be added in PloneSite
+        if ILanguageRootFolder.providedBy(self.context):
+            # LRF can't become minisite
+            return False
+        parent = self.context.aq_parent
+        if not IPloneSiteRoot.providedBy(parent) and not ILanguageRootFolder.providedBy(
+            parent
+        ):
+            # Minisite can only be added in PloneSite / LRF
             return False
         if IImioSmartwebSubsite.providedBy(self.context):
             # Subsite can't be converted in minisite
             return False
-        return IFolder.providedBy(self.context) and not self.enabled
+        return IFolder.providedBy(self.context) and not self.enabled()
 
-    @property
     def enabled(self):
         return IImioSmartwebMinisite.providedBy(self.context)
