@@ -84,6 +84,9 @@ class TestVocabularies(ImioSmartwebTestCase):
     def test_bootstrap_css(self):
         self.assertVocabularyLen("imio.smartweb.vocabulary.BootstrapCSS", 6)
 
+    def test_orientation(self):
+        self.assertVocabularyLen("imio.smartweb.vocabulary.Orientation", 3)
+
     def test_subsite_display_mode(self):
         self.assertVocabularyLen("imio.smartweb.vocabulary.SubsiteDisplayMode", 3)
 
@@ -188,7 +191,7 @@ class TestVocabularies(ImioSmartwebTestCase):
         self.assertVocabularyLen("imio.smartweb.vocabulary.Alignment", 4)
 
     def test_image_size(self):
-        self.assertVocabularyLen("imio.smartweb.vocabulary.ImageSize", 3)
+        self.assertVocabularyLen("imio.smartweb.vocabulary.ImageSize", 2)
 
     def test_concat_category_topics_vocabulary(self):
         self.assertVocabularyLen("imio.smartweb.vocabulary.CategoryAndTopics", 126)
@@ -259,13 +262,13 @@ class TestVocabularies(ImioSmartwebTestCase):
         json_agendas_raw_mock = get_json("resources/json_events_agendas_raw_mock.json")
         url = f"{config.EVENTS_URL}/imio-events-entity/@search?portal_type=imio.events.Agenda&sort_on=sortable_title&b_size=1000000&metadata_fields=UID"
         m.get(url, text=json.dumps(json_agendas_raw_mock))
-        url = f"{config.EVENTS_URL}/@search?selected_agendas=64f4cbee9a394a018a951f6d94452914&&selected_agendas=96d3e3299dc74386943e12c4f4fd0b8a&portal_type=imio.events.Event&metadata_fields=category&metadata_fields=topics&metadata_fields=start&metadata_fields=end&metadata_fields=has_leadimage&metadata_fields=breadcrumb&metadata_fields=UID&event_dates.query=2021-11-15&event_dates.range=min"
-        json_rest_events = get_json("resources/json_rest_events.json")
+        url = f"{config.EVENTS_URL}/@search?selected_agendas=64f4cbee9a394a018a951f6d94452914&selected_agendas=96d3e3299dc74386943e12c4f4fd0b8a&portal_type=imio.events.Event&metadata_fields=category&metadata_fields=topics&metadata_fields=start&metadata_fields=end&metadata_fields=has_leadimage&metadata_fields=breadcrumb&metadata_fields=UID&event_dates.query=2021-11-15&event_dates.range=min&b_size=1000000"
+        json_rest_events = get_json("resources/json_rest_events_with_breadcrumbs.json")
         m.get(url, text=json.dumps(json_rest_events))
         vocabulary = get_vocabulary("imio.smartweb.vocabulary.EventsFromEntity")
         self.assertEqual(
-            vocabulary.getTermByToken("1178188bddde4ced95a6cf8bf04c443b").title,
-            "belleville >> communal >> Bon pied, bon oeil",
+            vocabulary.getTermByToken("97902f2e26774a369035117d56381a2a").title,
+            "Belleville » Accueil temps libre » Journée de l'ATL",
         )
 
     @requests_mock.Mocker()
