@@ -9,6 +9,7 @@ import "./Events.scss";
 import useFilterQuery from "../../hooks/useFilterQuery";
 import { Provider, Translate } from "react-translated";
 import translation from '../../utils/translation';
+import moment from "moment";
 
 export default function Events(props) {
     return (
@@ -20,6 +21,7 @@ export default function Events(props) {
                     proposeUrl={props.proposeUrl}
                     batchSize={props.batchSize}
                     displayMap={props.displayMap}
+                    language={props.currentLanguage}
                 />
             </Provider>
         </Router>
@@ -28,7 +30,7 @@ export default function Events(props) {
 function EventsView(props) {
     const queryString = require("query-string");
     const { u, ...parsed } = Object.assign(
-        { b_start: 0, fullobjects: 1 },
+        { b_start: 0, fullobjects: 1, "event_dates.query":[moment().format('YYYY-MM-DD')],"event_dates.range":"min"},
         queryString.parse(useFilterQuery().toString())
     );
     const [itemsArray, setItemsArray] = useState([]);
@@ -48,6 +50,7 @@ function EventsView(props) {
                 Accept: "application/json",
             },
             params: filters,
+            paramsSerializer: { indexes: null },
             load: loadMoreLaunch,
         },
         []
@@ -132,7 +135,6 @@ function EventsView(props) {
     }
 
     const divLoader = <div className="lds-roller-container"><div className="lds-roller"><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div></div>;
-
     return (
         <div className={`ref ${displayMap ? "view-map" : "no-map"}`}>
             <div
@@ -148,6 +150,7 @@ function EventsView(props) {
                         url={props.queryFilterUrl}
                         activeFilter={filters}
                         onChange={filtersChange}
+                        language={props.language}
                     />
                     {props.proposeUrl &&
                         (
