@@ -3,6 +3,8 @@ import Select from "react-select";
 import { useHistory } from "react-router-dom";
 import useAxios from "../../../hooks/useAxios";
 import { Translator } from "react-translated";
+import DateFilter from "../../Filters/DateFilter";
+import moment from "moment";
 
 function Filters(props) {
     let history = useHistory();
@@ -10,6 +12,11 @@ function Filters(props) {
     const [inputValues, setInputValues] = useState(props.activeFilter);
     const [topicsFilter, setTopicsFilter] = useState(null);
     const [categoryFilter, setCategoryFilter] = useState(null);
+
+    // const [dates, setDates] = useState({ start: moment().format('YYYY-MM-DD'), end: null});
+    const [dates, setDates] = useState(null);
+
+    // Get data
     const { response, error, isLoading } = useAxios({
         method: "get",
         url: "",
@@ -18,6 +25,7 @@ function Filters(props) {
             Accept: "application/json",
         },
         params: inputValues,
+        paramsSerializer: { indexes: null }
     });
 
     useEffect(() => {
@@ -109,7 +117,22 @@ function Filters(props) {
             };
         },
     };
-    
+    useEffect(() => {
+        if (dates) {
+            setInputValues(prevState => {
+                if (dates["event_dates.query"].length > 1) {
+                    const { "event_dates.range": _, ...rest } = dates;
+                    const newValue = "min:max";
+                    return { ...prevState, ...rest, "event_dates.range": newValue };
+                } else if (dates["event_dates.query"].every(item => item === null)) {
+                    return { ...prevState, "event_dates.query": [moment().format('YYYY-MM-DD')], "event_dates.range": "min" }
+                }
+                else {
+                    return { ...prevState, ...dates, "event_dates.range": "min" };
+                }
+            });
+        }
+    }, [dates]);
     return (
         <React.Fragment>
             <form className="r-filter" onSubmit={handleSubmit}>
@@ -117,17 +140,17 @@ function Filters(props) {
                 <div className="r-filter-search">
                     <Translator>
                         {({ translate }) => (
-                        <input
-                            className="input-custom-class"
-                            name="SearchableText"
-                            type="text"
-                            value={inputValues.SearchableText}
-                            onChange={onChangeHandler}
-                            placeholder={translate({
-                                text: 'Recherche'
-                              })}
-                        />
-                    )}
+                            <input
+                                className="input-custom-class"
+                                name="SearchableText"
+                                type="text"
+                                value={inputValues.SearchableText}
+                                onChange={onChangeHandler}
+                                placeholder={translate({
+                                    text: 'Recherche'
+                                })}
+                            />
+                        )}
                     </Translator>
                     <button type="submit"></button>
                 </div>
@@ -165,14 +188,18 @@ function Filters(props) {
                             options={categoryFilter && categoryFilter}
                             placeholder={translate({
                                 text: 'Catégories'
-                              })}
+                            })}
                             value={actCategory && actCategory[0]}
                         />
                     )}
                 </Translator>
             </div>
+
+            <div className="r-filter  schedul-Filter">
+                <DateFilter language={props.language} setDates={setDates} />
+            </div>
         </React.Fragment>
     );
 }
 
-export default Filters;
+export default Filters;
\ No newline at end of file
